==> ldap-account-manager_5.5.orig.tar.bz2: ldap-account-manager-5.5/templates/lib/extra/ckeditor/plugins/specialchar/dialogs/lang/fi.js <==
﻿/**
 * @license Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or http://ckeditor.com/license
 */

CKEDITOR.plugins.setLang( 'specialchar', 'fi', {
	euro: 'Euron merkki',
	lsquo: 'Vasen yksittäinen lainausmerkki',
	rsquo: 'Oikea yksittäinen lainausmerkki',
	ldquo: 'Vasen kaksoislainausmerkki',
	rdquo: 'Oikea kaksoislainausmerkki',
	ndash: 'En dash', // MISSING
	mdash: 'Em dash', // MISSING
	iexcl: 'Inverted exclamation mark', // MISSING
	cent: 'Sentin merkki',
	pound: 'Punnan merkki',
	curren: 'Valuuttamerkki',
	yen: 'Yenin merkki',
	brvbar: 'Broken bar', // MISSING
	sect: 'Section sign', // MISSING
	uml: 'Diaeresis', // MISSING
	copy: 'Copyright sign', // MISSING
	ordf: 'Feminine ordinal indicator', // MISSING
	laquo: 'Left-pointing double angle quotation mark', // MISSING
	not: 'Not sign', // MISSING
	reg: 'Rekisteröity merkki',
	macr: 'Macron', // MISSING
	deg: 'Asteen merkki',
	sup2: 'Yläindeksi kaksi',
	sup3: 'Yläindeksi kolme',
	acute: 'Acute accent', // MISSING
	micro: 'Mikron merkki',
	para: 'Pilcrow sign', // MISSING
	middot: 'Middle dot', // MISSING
	cedil: 'Cedilla', // MISSING
	sup1: 'Yläindeksi yksi',
	ordm: 'Masculine ordinal indicator', // MISSING
	raquo: 'Right-pointing double angle quotation mark', // MISSING
	frac14: 'Vulgar fraction one quarter', // MISSING
	frac12: 'Vulgar fraction one half', // MISSING
	frac34: 'Vulgar fraction three quarters', // MISSING
	iquest: 'Ylösalaisin oleva kysymysmerkki',
	Agrave: 'Latin capital letter A with grave accent', // MISSING
	Aacute: 'Latin capital letter A with acute accent', // MISSING
	Acirc: 'Latin capital letter A with circumflex', // MISSING
	Atilde: 'Latin capital letter A with tilde', // MISSING
	Auml: 'Latin capital letter A with diaeresis', // MISSING
	Aring: 'Latin capital letter A with ring above', // MISSING
	AElig: 'Latin Capital letter Æ', // MISSING
	Ccedil: 'Latin capital letter C with cedilla', // MISSING
	Egrave: 'Latin capital letter E with grave accent', // MISSING
	Eacute: 'Latin capital letter E with acute accent', // MISSING
	Ecirc: 'Latin capital letter E with circumflex', // MISSING
	Euml: 'Latin capital letter E with diaeresis', // MISSING
	Igrave: 'Latin capital letter I with grave accent', // MISSING
	Iacute: 'Latin capital letter I with acute accent', // MISSING
	Icirc: 'Latin capital letter I with circumflex', // MISSING
	Iuml: 'Latin capital letter I with diaeresis', // MISSING
	ETH: 'Latin capital letter Eth', // MISSING
	Ntilde: 'Latin capital letter N with tilde', // MISSING
	Ograve: 'Latin capital letter O with grave accent', // MISSING
	Oacute: 'Latin capital letter O with acute accent', // MISSING
	Ocirc: 'Latin capital letter O with circumflex', // MISSING
	Otilde: 'Latin capital letter O with tilde', // MISSING
	Ouml: 'Latin capital letter O with diaeresis', // MISSING
	times: 'Kertomerkki',
	Oslash: 'Latin capital letter O with stroke', // MISSING
	Ugrave: 'Latin capital letter U with grave accent', // MISSING
	Uacute: 'Latin capital letter U with acute accent', // MISSING
	Ucirc: 'Latin capital letter U with circumflex', // MISSING
	Uuml: 'Latin capital letter U with diaeresis', // MISSING
	Yacute: 'Latin capital letter Y with acute accent', // MISSING
	THORN: 'Latin capital letter Thorn', // MISSING
	szlig: 'Latin small letter sharp s', // MISSING
	agrave: 'Latin small letter a with grave accent', // MISSING
	aacute: 'Latin small letter a with acute accent', // MISSING
	acirc: 'Latin small letter a with circumflex', // MISSING
	atilde: 'Latin small letter a with tilde', // MISSING
	auml: 'Latin small letter a with diaeresis', // MISSING
	aring: 'Latin small letter a with ring above', // MISSING
	aelig: 'Latin small letter æ', // MISSING
	ccedil: 'Latin small letter c with cedilla', // MISSING
	egrave: 'Latin small letter e with grave accent', // MISSING
	eacute: 'Latin small letter e with acute accent', // MISSING
	ecirc: 'Latin small letter e with circumflex', // MISSING
	euml: 'Latin small letter e with diaeresis', // MISSING
	igrave: 'Latin small letter i with grave accent', // MISSING
	iacute: 'Latin small letter i with acute accent', // MISSING
	icirc: 'Latin small letter i with circumflex', // MISSING
	iuml: 'Latin small letter i with diaeresis', // MISSING
	eth: 'Latin small letter eth', // MISSING
	ntilde: 'Latin small letter n with tilde', // MISSING
	ograve: 'Latin small letter o with grave accent', // MISSING
	oacute: 'Latin small letter o with acute accent', // MISSING
	ocirc: 'Latin small letter o with circumflex', // MISSING
	otilde: 'Latin small letter o with tilde', // MISSING
	ouml: 'Latin small letter o with diaeresis', // MISSING
	divide: 'Jakomerkki',
	oslash: 'Latin small letter o with stroke', // MISSING
	ugrave: 'Latin small letter u with grave accent', // MISSING
	uacute: 'Latin small letter u with acute accent', // MISSING
	ucirc: 'Latin small letter u with circumflex', // MISSING
	uuml: 'Latin small letter u with diaeresis', // MISSING
	yacute: 'Latin small letter y with acute accent', // MISSING
	thorn: 'Latin small letter thorn', // MISSING
	yuml: 'Latin small letter y with diaeresis', // MISSING
	OElig: 'Latin capital ligature OE', // MISSING
	oelig: 'Latin small ligature oe', // MISSING
	'372': 'Latin capital letter W with circumflex', // MISSING
	'374': 'Latin capital letter Y with circumflex', // MISSING
	'373': 'Latin small letter w with circumflex', // MISSING
	'375': 'Latin small letter y with circumflex', // MISSING
	sbquo: 'Single low-9 quotation mark', // MISSING
	'8219': 'Single high-reversed-9 quotation mark', // MISSING
	bdquo: 'Double low-9 quotation mark', // MISSING
	hellip: 'Horizontal ellipsis', // MISSING
	trade: 'Tavaramerkki merkki',
	'9658': 'Black right-pointing pointer', // MISSING
	bull: 'Bullet', // MISSING
	rarr: 'Nuoli oikealle',
	rArr: 'Kaksoisnuoli oikealle',
	hArr: 'Kaksoisnuoli oikealle ja vasemmalle',
	diams: 'Black diamond suit', // MISSING
	asymp: 'Noin'
} );

==> ldap-account-manager_6.7.orig.tar.bz2: ldap-account-manager-6.7/templates/lib/extra/ckeditor/plugins/specialchar/dialogs/lang/fi.js <==
﻿/**
 * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'specialchar', 'fi', {
	euro: 'Euron merkki',
	lsquo: 'Vasen yksittäinen lainausmerkki',
	rsquo: 'Oikea yksittäinen lainausmerkki',
	ldquo: 'Vasen kaksoislainausmerkki',
	rdquo: 'Oikea kaksoislainausmerkki',
	ndash: 'En dash', // MISSING
	mdash: 'Em dash', // MISSING
	iexcl: 'Inverted exclamation mark', // MISSING
	cent: 'Sentin merkki',
	pound: 'Punnan merkki',
	curren: 'Valuuttamerkki',
	yen: 'Yenin merkki',
	brvbar: 'Broken bar', // MISSING
	sect: 'Section sign', // MISSING
	uml: 'Diaeresis', // MISSING
	copy: 'Copyright sign', // MISSING
	ordf: 'Feminine ordinal indicator', // MISSING
	laquo: 'Left-pointing double angle quotation mark', // MISSING
	not: 'Not sign', // MISSING
	reg: 'Rekisteröity merkki',
	macr: 'Macron', // MISSING
	deg: 'Asteen merkki',
	sup2: 'Yläindeksi kaksi',
	sup3: 'Yläindeksi kolme',
	acute: 'Acute accent', // MISSING
	micro: 'Mikron merkki',
	para: 'Pilcrow sign', // MISSING
	middot: 'Middle dot', // MISSING
	cedil: 'Cedilla', // MISSING
	sup1: 'Yläindeksi yksi',
	ordm: 'Masculine ordinal indicator', // MISSING
	raquo: 'Right-pointing double angle quotation mark', // MISSING
	frac14: 'Vulgar fraction one quarter', // MISSING
	frac12: 'Vulgar fraction one half', // MISSING
	frac34: 'Vulgar fraction three quarters', // MISSING
	iquest: 'Ylösalaisin oleva kysymysmerkki',
	Agrave: 'Latin capital letter A with grave accent', // MISSING
	Aacute: 'Latin capital letter A with acute accent', // MISSING
	Acirc: 'Latin capital letter A with circumflex', // MISSING
	Atilde: 'Latin capital letter A with tilde', // MISSING
	Auml: 'Latin capital letter A with diaeresis', // MISSING
	Aring: 'Latin capital letter A with ring above', // MISSING
	AElig: 'Latin capital letter Æ', // MISSING
	Ccedil: 'Latin capital letter C with cedilla', // MISSING
	Egrave: 'Latin capital letter E with grave accent', // MISSING
	Eacute: 'Latin capital letter E with acute accent', // MISSING
	Ecirc: 'Latin capital letter E with circumflex', // MISSING
	Euml: 'Latin capital letter E with diaeresis', // MISSING
	Igrave: 'Latin capital letter I with grave accent', // MISSING
	Iacute: 'Latin capital letter I with acute accent', // MISSING
	Icirc: 'Latin capital letter I with circumflex', // MISSING
	Iuml: 'Latin capital letter I with diaeresis', // MISSING
	ETH: 'Latin capital letter Eth', // MISSING
	Ntilde: 'Latin capital letter N with tilde', // MISSING
	Ograve: 'Latin capital letter O with grave accent', // MISSING
	Oacute: 'Latin capital letter O with acute accent', // MISSING
	Ocirc: 'Latin capital letter O with circumflex', // MISSING
	Otilde: 'Latin capital letter O with tilde', // MISSING
	Ouml: 'Latin capital letter O with diaeresis', // MISSING
	times: 'Kertomerkki',
	Oslash: 'Latin capital letter O with stroke', // MISSING
	Ugrave: 'Latin capital letter U with grave accent', // MISSING
	Uacute: 'Latin capital letter U with acute accent', // MISSING
	Ucirc: 'Latin capital letter U with circumflex', // MISSING
	Uuml: 'Latin capital letter U with diaeresis', // MISSING
	Yacute: 'Latin capital letter Y with acute accent', // MISSING
	THORN: 'Latin capital letter Thorn', // MISSING
	szlig: 'Latin small letter sharp s', // MISSING
	agrave: 'Latin small letter a with grave accent', // MISSING
	aacute: 'Latin small letter a with acute accent', // MISSING
	acirc: 'Latin small letter a with circumflex', // MISSING
	atilde: 'Latin small letter a with tilde', // MISSING
	auml: 'Latin small letter a with diaeresis', // MISSING
	aring: 'Latin small letter a with ring above', // MISSING
	aelig: 'Latin small letter æ', // MISSING
	ccedil: 'Latin small letter c with cedilla', // MISSING
	egrave: 'Latin small letter e with grave accent', // MISSING
	eacute: 'Latin small letter e with acute accent', // MISSING
	ecirc: 'Latin small letter e with circumflex', // MISSING
	euml: 'Latin small letter e with diaeresis', // MISSING
	igrave: 'Latin small letter i with grave accent', // MISSING
	iacute: 'Latin small letter i with acute accent', // MISSING
	icirc: 'Latin small letter i with circumflex', // MISSING
	iuml: 'Latin small letter i with diaeresis', // MISSING
	eth: 'Latin small letter eth', // MISSING
	ntilde: 'Latin small letter n with tilde', // MISSING
	ograve: 'Latin small letter o with grave accent', // MISSING
	oacute: 'Latin small letter o with acute accent', // MISSING
	ocirc: 'Latin small letter o with circumflex', // MISSING
	otilde: 'Latin small letter o with tilde', // MISSING
	ouml: 'Latin small letter o with diaeresis', // MISSING
	divide: 'Jakomerkki',
	oslash: 'Latin small letter o with stroke', // MISSING
	ugrave: 'Latin small letter u with grave accent', // MISSING
	uacute: 'Latin small letter u with acute accent', // MISSING
	ucirc: 'Latin small letter u with circumflex', // MISSING
	uuml: 'Latin small letter u with diaeresis', // MISSING
	yacute: 'Latin small letter y with acute accent', // MISSING
	thorn: 'Latin small letter thorn', // MISSING
	yuml: 'Latin small letter y with diaeresis', // MISSING
	OElig: 'Latin capital ligature OE', // MISSING
	oelig: 'Latin small ligature oe', // MISSING
	'372': 'Latin capital letter W with circumflex', // MISSING
	'374': 'Latin capital letter Y with circumflex', // MISSING
	'373': 'Latin small letter w with circumflex', // MISSING
	'375': 'Latin small letter y with circumflex', // MISSING
	sbquo: 'Single low-9 quotation mark', // MISSING
	'8219': 'Single high-reversed-9 quotation mark', // MISSING
	bdquo: 'Double low-9 quotation mark', // MISSING
	hellip: 'Horizontal ellipsis', // MISSING
	trade: 'Tavaramerkki merkki',
	'9658': 'Black right-pointing pointer', // MISSING
	bull: 'Bullet', // MISSING
	rarr: 'Nuoli oikealle',
	rArr: 'Kaksoisnuoli oikealle',
	hArr: 'Kaksoisnuoli oikealle ja vasemmalle',
	diams: 'Black diamond suit', // MISSING
	asymp: 'Noin'
} );
